package com.pms.ocp.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.pms.ocp.mapper.OcpApiBaseMapper;
import com.pms.ocp.mapper.OcpApiTreeMapper;
import com.pms.ocp.model.dto.*;
import com.pms.ocp.model.entity.OcpApiBase;
import com.pms.ocp.model.entity.OcpApiGroup;
import com.pms.ocp.service.OcpApiTreeService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;


@Service
public class OcpApiTreeServiceImpl extends ServiceImpl<OcpApiTreeMapper,OcpApiGroup> implements OcpApiTreeService {


    @Autowired
    private OcpApiTreeMapper mapper;

    @Autowired
    private OcpApiBaseMapper ocpApiBaseMapper;

    /**
     * 服务树分类
     * @return
     */

    @Override
    public ApiTreeGroupDto  getByGroup() {

        //服务树全表数据
        List<OcpApiGroup> ocpApiGroups = mapper.selectList(null);

        //服务树分类对象
        ApiTreeGroupDto apiTreeGroupList = new ApiTreeGroupDto();
        //一级服务分类
        List<OneTreeUpList> oneTreeUpLists = new ArrayList<>();

        for (OcpApiGroup ocpApiGroup : ocpApiGroups) {
            //判断数据状态
            if (!(ocpApiGroup.getIsDelete() == 0)) {
                //一级服务对象
                OneTreeUpList oneTreeUpList = new OneTreeUpList();
//                判断数据是否有上级服务分类
                if ("".equals(ocpApiGroup.getApiGroupPcode())) {
                        BeanUtils.copyProperties(ocpApiGroup, oneTreeUpList);
                        oneTreeUpLists.add(oneTreeUpList);

                }
            }


        }
        List<TwoDownList> twoDownLists = twoTreeLists(oneTreeUpLists, ocpApiGroups);
        List<ThreeTreeList> threeTreeLists = threeTreeLists(twoDownLists, ocpApiGroups);
        apiTreeGroupList.setOneupList(oneTreeUpLists);
        apiTreeGroupList.setTwoList(twoDownLists);
        apiTreeGroupList.setThreeList(threeTreeLists);

            return apiTreeGroupList;
    }

    /**
     * 二级目录
     * @param oneTreeUpLists
     * @return
     */
    public List<TwoDownList> twoTreeLists(List<OneTreeUpList> oneTreeUpLists,List<OcpApiGroup> ocpApiGroups){

        List<TwoDownList> twoTreeLists = new ArrayList<>();

        //服务树全表数据

        for (OneTreeUpList oneTreeUpList : oneTreeUpLists) {
            String code = oneTreeUpList.getApiGroupCode();
            for (OcpApiGroup ocpApiGroup : ocpApiGroups ) {
                    if (code.equals(ocpApiGroup.getApiGroupPcode())) {
                        TwoDownList twoDownList = new TwoDownList();
                        BeanUtils.copyProperties(ocpApiGroup,twoDownList);
                        twoTreeLists.add(twoDownList);

                    }
            }
        }

        return twoTreeLists;

    }
    /**
     * 三级目录
     * @param twoDownLists
     * @return
     */
    public List<ThreeTreeList> threeTreeLists(List<TwoDownList> twoDownLists,List<OcpApiGroup> ocpApiGroups){
        List<ThreeTreeList> threeTreeLists = new ArrayList<>();


        for (TwoDownList twoDownList : twoDownLists) {
            for (OcpApiGroup ocpApiGroup : ocpApiGroups) {
                String code = twoDownList.getApiGroupCode();
                if (code.equals(ocpApiGroup.getApiGroupPcode())){
                    ThreeTreeList threeTreeList = new ThreeTreeList();
                    BeanUtils.copyProperties(ocpApiGroup,threeTreeList);
                    threeTreeLists.add(threeTreeList);
                   /* threeTreeList.setThreeList(ocpApiGroup);
                    threeTreeLists.add(threeTreeList);*/
                }
            }

        }
        return threeTreeLists;

    }

        /**
         * 新增服务分类
         *
         * @param ocpApiGroupDtos
         */
        @Override
        public boolean insertTree(OcpApiGroupDtos ocpApiGroupDtos) {

            boolean flag = true;
            List<OcpApiGroup> ocpApiGroups = mapper.selectList(null);
            for (OcpApiGroup ocpApiGroup : ocpApiGroups) {
                if (ocpApiGroup.getApiGroupCode().equals(ocpApiGroupDtos.getApiGroupCode())){
                    flag = false;
                    break;
                }
            }
            if (flag == true) {
                OcpApiBase ocpApiBase = new OcpApiBase();
                ocpApiBase.setApiCode(ocpApiGroupDtos.getApiGroupCode());
                BeanUtils.copyProperties(ocpApiGroupDtos, ocpApiBase);
                ocpApiBase.setApiName("新增服务分类");
                Timestamp timestamp = new Timestamp(System.currentTimeMillis());
                ocpApiBase.setApiMtime(timestamp);
                ocpApiBase.setApiCtime(ocpApiGroupDtos.getApiGroupCtime());
                ocpApiBase.setApiUserId(ocpApiGroupDtos.getApiGroupUserId());
                ocpApiBase.setObjId("");

                OcpApiGroup ocpApiGroup1 = new OcpApiGroup();
                ocpApiGroup1.setObjId("");
                BeanUtils.copyProperties(ocpApiGroupDtos, ocpApiGroup1);
                ocpApiBaseMapper.insert(ocpApiBase);
                mapper.insert(ocpApiGroup1);

            }
            return flag;

        }


    /**
     * 修改服务分类
     *
     * @param
     */
    @Override
    public void updataOcpTree(OcpApiGroup ocpApiGroup) {
        mapper.updateById(ocpApiGroup);
    }



    /**
     * 删除服务分类
     *
     * @param ocpApiGroup
     */
    @Override
    public boolean deleteOcpTree(OcpApiGroup ocpApiGroup) {
        String objId = ocpApiGroup.getObjId();
        OcpApiGroup ocpApiGroup1 = mapper.selectById(objId);

        if(StringUtils.isBlank(ocpApiGroup1.getApiGroupPcode())){
            mapper.deleteById(objId);
            return true;
        }else {
            return false;
        }


    }


}
